'use strict';

/*
* No need to customize. All required changes go into dataAccess.js
*/

const dataAccess = require('./data/dataAccess');

module.exports = {
  metadata: () => ({
    name: 'cxs.CheckOrderStatus',
    properties: {
      userId: { required: true, type: 'string' },
      orderId: { required: true, type: 'string' },
      variable: { required: true, type: 'string' }
    },
    supportedActions: ['noOrderFound', 'orderFound']
  }),

  invoke: (context, done) => {
    // Retrieve the value of the 'human' component property.
    const { userId } = context.properties();
    const { orderId } = context.properties();
    const { variable } = context.properties();

    let order = dataAccess.checkStatus(userId, orderId);
    //navigate dialog flow based on whether or not an order was found
    if (order == null) {
      context.transition("noOrderFound");
    }
    else {
      context.transition("orderFound");
    }

    //set order array to the variable passed as an argument
    context.variable(variable, order);
    //continue to next dialog flow state without user interaction
    context.keepTurn(true);
    done();
  }
};
