'use strict';
/*
 * This custom component queries opening hours for a city and locale. The result of the 
 * query is expected as an array of strings in a language matching the locale.
 *
 * @param {string} city - name of the city the store(s) are in
 * @param {string} variable - name of dialog flow variable to update with an array of message strings
 * @author Frank Nimphius, 2021
 */

//loads the message mockup for this sample
const openingHoursSearch = require('./OpeningHoursSearch');

module.exports = {
  
  metadata: () => ({
    name: 'faq.openingHoursFinder',
    properties: {
      variable: { required: true, type: 'string' },
      city: { required: true, type: 'string' },
    },
    supportedActions: ['notfound', 'found']
  }),
  invoke: (context, done) => {
    const { variable, city } = context.properties();
    var languageTag = context.variable('profile.languageTag');
    var locale = context.variable('profile.locale');

    //profile.languageTag overwrites the profile.locale setting because it is
    //set at runtime based on the language detected for a user
    locale = languageTag != null ? languageTag : (locale != null ? locale : 'en');

    if (openingHoursSearch.hasStoresInCity(city)) {
      let arrayOfMessages = openingHoursSearch.getOpeningHours(city, locale);
      let resultArrayOfMessages = [];

      //add blank lines as paragraphs
      arrayOfMessages.forEach(element => {
        resultArrayOfMessages.push(element);
        //add a blank line
        resultArrayOfMessages.push(" ");
      });
      
      context.variable(variable, resultArrayOfMessages);
      context.transition('found');
    }
    else {
      context.logger().info("We could not find stores in " + city);
      context.transition('notfound');
    }

    context.keepTurn(true);
    done();
  }
};
