/*
 * It is considered good coding practice to separate backend access logic from custom component logic. This 
 * class is a helper method called by the custom component and implements the search to a backend.
 * 
 * In this sample, the backend is a JSON file deployed with the custom component. To query your backend service
 * you change the code for the hasStoreInCity function (returns true / false) and the getOpeningHours function
 * (returns array of strings with opening hours information)
 * 
 * To call a remote backend, you can use the node-fetch Node module that is integrated in the bots-node-sdk.
 * See: https://github.com/node-fetch/node-fetch. 
 * 
 * To return opening times for specific stores in a city, you need to extend the sample and add an address to 
 * the search condition.
 *  
 * @author Frank Nimphius, 2021
 */

const fs = require('fs');

module.exports = {

    /*
    * verifies if a given city has stores
    */
    hasStoresInCity: (city) => {
        let jsondata = fs.readFileSync(__dirname+'/data/data.json');
        let data = JSON.parse(jsondata);
        
        return data.en.hasOwnProperty(city)? true : false;
    },


    /*
     * get opening time message for a given locale
     */
    getOpeningHours: (city, locale) => {
        let jsondata = fs.readFileSync(__dirname+'/data/data.json');
        let data = JSON.parse(jsondata);

        switch (locale) {
            case "de":
                //check if locale exist
                if (data.de != null) {
                    return data.de[city];
                }
                break;
            //default language is English
            default:
                //default message string is for English (en)
                return data.en[city];
        }
    }
}